@@ -245,8 +245,8 @@ photos_delete_notification_new (GList *items)
   g_object_new (PHOTOS_TYPE_DELETE_NOTIFICATION,
                 "column-spacing", 12,
                 "items", items,
-                "margin-left", 12,
-                "margin-right", 12,
+                "margin-start", 12,
+                "margin-end", 12,
                 "orientation", GTK_ORIENTATION_HORIZONTAL,
                 NULL);
 }
