@@ -27,7 +27,6 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <libgd/gd.h>
 
 #include "photos-enums.h"
 #include "photos-icons.h"
@@ -41,12 +40,10 @@ struct _PhotosPreviewNavButtonsPrivate
 {
   GtkTreeModel *model;
   GtkTreePath *current_path;
-  GtkWidget *favorite_button;
   GtkWidget *next_widget;
   GtkWidget *overlay;
   GtkWidget *prev_widget;
   GtkWidget *preview_view;
-  GtkWidget *toolbar_widget;
   PhotosBaseManager *item_mngr;
   PhotosPreviewAction action;
   gboolean enable_next;
@@ -78,23 +75,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 G_DEFINE_TYPE_WITH_PRIVATE (PhotosPreviewNavButtons, photos_preview_nav_buttons, G_TYPE_OBJECT);
 
 
-static void photos_preview_nav_buttons_update_favorite (PhotosPreviewNavButtons *self, gboolean favorite);
-
-
-static void
-photos_preview_nav_buttons_active_changed (PhotosPreviewNavButtons *self, GObject *object)
-{
-  PhotosBaseItem *item = PHOTOS_BASE_ITEM (object);
-  gboolean favorite;
-
-  if (object == NULL)
-    return;
-
-  favorite = photos_base_item_is_favorite (item);
-  photos_preview_nav_buttons_update_favorite (self, favorite);
-}
-
-
 static void
 photos_preview_nav_buttons_fade_in_button (PhotosPreviewNavButtons *self, GtkWidget *widget)
 {
@@ -133,21 +113,6 @@ photos_preview_nav_buttons_fade_out_button (PhotosPreviewNavButtons *self, GtkWi
 }
 
 
-static void
-photos_preview_nav_buttons_favorite_clicked (PhotosPreviewNavButtons *self)
-{
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-  PhotosBaseItem *item;
-  gboolean favorite;
-
-  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (priv->item_mngr));
-  favorite = photos_base_item_is_favorite (item);
-  photos_base_item_set_favorite (item, !favorite);
-
-  photos_preview_nav_buttons_update_favorite (self, !favorite);
-}
-
-
 static gboolean
 photos_preview_nav_buttons_auto_hide (PhotosPreviewNavButtons *self)
 {
@@ -155,7 +120,6 @@ photos_preview_nav_buttons_auto_hide (PhotosPreviewNavButtons *self)
 
   photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
   photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
-  photos_preview_nav_buttons_fade_out_button (self, priv->toolbar_widget);
   priv->auto_hide_id = 0;
   return G_SOURCE_REMOVE;
 }
@@ -206,35 +170,6 @@ photos_preview_nav_buttons_leave_notify (PhotosPreviewNavButtons *self)
 }
 
 
-static void
-photos_preview_nav_buttons_update_favorite (PhotosPreviewNavButtons *self, gboolean favorite)
-{
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-  GtkStyleContext *context;
-  gchar *favorite_label;
-
-  g_signal_handlers_block_by_func (priv->favorite_button, photos_preview_nav_buttons_favorite_clicked, self);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->favorite_button), favorite);
-  g_signal_handlers_unblock_by_func (priv->favorite_button, photos_preview_nav_buttons_favorite_clicked, self);
-
-  context = gtk_widget_get_style_context (priv->favorite_button);
-  if (favorite)
-    {
-      favorite_label = g_strdup (_("Remove from favorites"));
-      gtk_style_context_add_class (context, "photos-favorite");
-    }
-  else
-    {
-      favorite_label = g_strdup (_("Add to favorites"));
-      gtk_style_context_remove_class (context, "photos-favorite");
-    }
-
-  gtk_widget_reset_style (priv->favorite_button);
-  gtk_widget_set_tooltip_text (priv->favorite_button, favorite_label);
-  g_free (favorite_label);
-}
-
-
 static void
 photos_preview_nav_buttons_update_visibility (PhotosPreviewNavButtons *self)
 {
@@ -251,12 +186,9 @@ photos_preview_nav_buttons_update_visibility (PhotosPreviewNavButtons *self)
     {
       enable_prev = FALSE;
       enable_next = FALSE;
-      photos_preview_nav_buttons_fade_out_button (self, priv->toolbar_widget);
       goto out;
     }
 
-  photos_preview_nav_buttons_fade_in_button (self, priv->toolbar_widget);
-
   tmp = iter;
   enable_prev = gtk_tree_model_iter_previous (priv->model, &tmp);
 
@@ -377,7 +309,6 @@ photos_preview_nav_buttons_constructed (GObject *object)
   GtkStyleContext *context;
   GtkWidget *button;
   GtkWidget *image;
-  GtkWidget *toolbar;
 
   G_OBJECT_CLASS (photos_preview_nav_buttons_parent_class)->constructed (object);
 
@@ -439,34 +370,6 @@ photos_preview_nav_buttons_constructed (GObject *object)
                             G_CALLBACK (photos_preview_nav_buttons_leave_notify),
                             self);
 
-  priv->toolbar_widget = gtk_revealer_new ();
-  gtk_widget_set_halign (priv->toolbar_widget, GTK_ALIGN_FILL);
-  gtk_widget_set_valign (priv->toolbar_widget, GTK_ALIGN_END);
-  gtk_revealer_set_transition_type (GTK_REVEALER (priv->toolbar_widget), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
-  gtk_overlay_add_overlay (GTK_OVERLAY (priv->overlay), priv->toolbar_widget);
-
-  toolbar = gtk_action_bar_new ();
-  context = gtk_widget_get_style_context (toolbar);
-  gtk_style_context_add_class (context, "osd");
-  gtk_container_add (GTK_CONTAINER (priv->toolbar_widget), toolbar);
-  g_signal_connect_swapped (toolbar,
-                            "enter-notify-event",
-                            G_CALLBACK (photos_preview_nav_buttons_enter_notify),
-                            self);
-  g_signal_connect_swapped (toolbar,
-                            "leave-notify-event",
-                            G_CALLBACK (photos_preview_nav_buttons_leave_notify),
-                            self);
-
-  priv->favorite_button = gd_header_toggle_button_new ();
-  gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (priv->favorite_button),
-                                           PHOTOS_ICON_FAVORITE_SYMBOLIC);
-  gtk_action_bar_pack_end (GTK_ACTION_BAR (toolbar), priv->favorite_button);
-  g_signal_connect_swapped (priv->favorite_button,
-                            "clicked",
-                            G_CALLBACK (photos_preview_nav_buttons_favorite_clicked),
-                            self);
-
   g_signal_connect_swapped (priv->overlay,
                             "motion-notify-event",
                             G_CALLBACK (photos_preview_nav_buttons_motion_notify),
@@ -537,10 +440,6 @@ photos_preview_nav_buttons_init (PhotosPreviewNavButtons *self)
   priv = self->priv;
 
   priv->item_mngr = photos_item_manager_dup_singleton ();
-  g_signal_connect_swapped (priv->item_mngr,
-                            "active-changed",
-                            G_CALLBACK (photos_preview_nav_buttons_active_changed),
-                            self);
 
   priv->action = PHOTOS_PREVIEW_ACTION_NONE;
 
@@ -634,7 +533,6 @@ photos_preview_nav_buttons_hide (PhotosPreviewNavButtons *self)
   priv->visible = FALSE;
   photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
   photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
-  photos_preview_nav_buttons_fade_out_button (self, priv->toolbar_widget);
 
   g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
 }
